PyXMake Developer Guide: PyXMake.VTL.py2x Namespace Reference

| PyXMake Developer Guide 1.0 PyXMake

Loading...
Searching...
No Matches
Functions
PyXMake.VTL.py2x Namespace Reference

## Functions
| main (BuildID, files=VTL.GetSourceCode(0), command=VTL.GetBuildCommand(0), libs=VTL.GetLinkDependency(0, 0, __arch), source=os.path.join(__mcd_core_path,"src"), include=[os.path.join(__mcd_core_path,"include", Utility.GetPlatform(), __arch, x) for x in VTL.GetIncludeDirectory(__mcd_core_path, 0, 4, __arch)], dependency=os.path.join(__mcd_core_path,"lib", Utility.GetPlatform(), __arch), output=os.path.join(__mcd_core_path,"bin", Utility.GetPlatform(), __arch), architecture=__arch, scratch=VTL.Scratch, verbosity=(2 if not Utility.IsDockerContainer() else 2), incremental=False, **kwargs)

## Detailed Description

    Triple-use minimum working example for PyXMake. This script can be
    executed in three different ways in varying levels of accessibility

    @note: Compile Fortran source as a shared library for Python
                 using f2py (Py2X in the future).
    Created on 20.03.2018

    @version:  1.0
    ----------------------------------------------------------------------------------------------
    @requires:
          - PyXMake, PyCODAC

    @change:
          -

    @author: garb_ma                                      [DLR-FA,STM Braunschweig]
    ----------------------------------------------------------------------------------------------

## Function Documentation

## ◆ main()

PyXMake.VTL.py2x.main | ( |  | BuildID,
|  |  | files = VTL.GetSourceCode(0),
|  |  | command = VTL.GetBuildCommand(0),
|  |  | libs = VTL.GetLinkDependency(0, 0, __arch),
|  |  | source = os.path.join(__mcd_core_path,"src"),
|  |  | include = [os.path.join(__mcd_core_path,"include",Utility.GetPlatform(),__arch, x) for x in VTL.GetIncludeDirectory(__mcd_core_path, 0, 4, __arch)],
|  |  | dependency = os.path.join(__mcd_core_path,"lib",Utility.GetPlatform(),__arch),
|  |  | output = os.path.join(__mcd_core_path,"bin",Utility.GetPlatform(),__arch),
|  |  | architecture = __arch,
|  |  | scratch = VTL.Scratch,
|  |  | verbosity = (2 if not Utility.IsDockerContainer() else 2),
|  |  | incremental = False,
|  | ** | kwargs )

    Main function to execute the script.

Definition at line 52 of file py2x.py.